; ---------------------------------------------------------------------------
;                              GET NEW BUYER
; ---------------------------------------------------------------------------
proc GetNewBuyer()
  private x, Lname, Fname, NewName,       ; NewName is array from name entry
          ID, FoundRec, IDRootCount
  CurrentProc = "GetNewBuyer"

  Fname = ""
  Lname = ""
  ID = ""
  FoundRec = 0
  j = 0
  IDRootCount = 0

  ; -----------------------------------------------------------------------
  ;                               Main Loop
  ; -----------------------------------------------------------------------
  while true

    GetNewName()        ; quit if it returns false
    if not retval then
      return
    endif

    MakeIDRoot()

    CheckDupeID()        ; add or go back to top
    if not retval then
      loop
    endif

    AddIDNbr()
    WaitMsg = "Add new buyer's address information now"
    return

  endwhile

endproc

writelib LIBNAME GetNewBuyer
release procs GetNewBuyer
? "GetNewBuyer()"
if row() >= 23 then setmargin 40 @ 1,0 endif



; ---------------------------------------------------------------------------
;                               GET NEW NAME
; ---------------------------------------------------------------------------
proc GetNewName()
  private x
  CurrentProc = "GetNewName"

  Fname = ""
  Lname = ""

  ins
  moveto [Lname]


  while true

    if isblank(WaitMsg) then
      WaitMsg = "Memleft() = " + strval(memleft())
    endif

    imagerights update

    wait field   prompt
      format("w40,al","Enter NEW BUYER's name:")+
      format("w40,ar"," [F2] when done"),
      format("w40,al","Press [Enter] to change fields.")+
      format("w40,ar","[Esc] to cancel")
      message WaitMsg
    until "Enter", "F2", "Esc"

    imagerights

    WaitMsg = ""

    switch

      case retval = "Enter":
        if field() = "Lname" then
          moveto [Fname]
        else
          moveto [Lname]
        endif

      case retval = "Esc":
        del
        return false

      case retval = "F2":
        if isblank([lname]) or isblank([fname]) then
          beep
          WaitMsg = "Both first and last names must be filled in."
          loop
        else
          Lname = [Lname]
          Fname = [Fname]
          del
          return true
        endif

    endswitch

  endwhile

endproc

writelib LIBNAME GetNewName
release procs GetNewName
? "GetNewName()"
if row() >= 23 then setmargin 40 @ 1,0 endif




; ---------------------------------------------------------------------------
;                              MAKE ID ROOT
; ---------------------------------------------------------------------------
proc MakeIDRoot()
  private x, j, L, Last, First
  CurrentProc = "MakeIDRoot"

  L = len(Lname)
  Last = ""
  for j from 1 to L
    x = substr(Lname,j,1)
    if x = " " or x = "." or x = "-" then
      loop
    else
      Last = Last + x
    endif
  endfor

  L = len(Fname)
  First = ""
  for j from 1 to L
    x = substr(Fname,j,1)
    if x = " " or x = "." or x = "-" then
      loop
    else
      First = First + x
    endif
  endfor

  j = len(Last)
  if j > 5
    then j = 5
  endif

  ID = upper(substr(Last,1,j))

  ID = upper(ID + substr(First,1,6-len(ID)))

  while match(ID,".. ",ID)
  endwhile

  while len(ID) < 6
    ID = ID + "_"
  endwhile

endproc

writelib LIBNAME MakeIDRoot
release procs MakeIDRoot
? "MakeIDRoot()"
if row() >= 23 then setmargin 40 @ 1,0 endif




; ---------------------------------------------------------------------------
;                              CHECK DUPE ID
; ---------------------------------------------------------------------------
proc CheckDupeID()
  private x
  CurrentProc = "CheckDupeID"

  ; -------------------------------------------------------------------
  ; check for possible duplicates
  ; -------------------------------------------------------------------
  BDMsg("Looking for possible duplicates to "+Lname,2,"reverse",0,false)

  IDRootCount = 0

  moveto [Buyer ID]

  locate pattern ID + ".."

  if retval then
    FoundRec = [Buyer ID]
    while retval
      IDRootCount = max(IDRootCount,numval(substr([Buyer ID],7,2)))
      skip
      if eot() then
        quitloop
      endif
      locate next pattern ID + ".."
    endwhile

    IDRootCount = IDRootCount + 1

    locate FoundRec

    while true
      imagerights readonly
      wait field   prompt
        "Other records similar to "+Lname+" found - review for possible dupes",
        "AltZ=see next;     " +
        "F2=add new '" + Lname + "';     Esc=cancel;"
        message "Memleft() = " + strval(memleft())
      until "F2", "Esc", "ZoomNext", "F7",
            "Up", "Down", "PgUp", "PgDn",
            "Dos", "DosBig", "Rotate"
      imagerights
      switch
        case retval = "F2":
          if not isformview() then
            formkey
          endif
          return true
        case retval = "Esc":
          return false
        case retval = "F7":
          formkey
        case retval = "ZoomNext":
          skip
          locate next pattern ID + ".."
          if not retval then
            beep
            Msg("No more possible dupes found",2,"reverse",0,false)
            showmenu
              "Add":         "Add new "+Lname,
              "Look Again":  "Go back to first possible duplicate",
              "Start Over":  "Start over with another new name"
            to Ans
            switch
              case Ans = "Add":
                if not isformview() then
                  formkey
                endif
                return true
              case Ans = "Look Again":
                locate pattern ID + ".."
                loop
              case Ans = "Start Over":
                if not isformview() then
                  formkey
                endif
                return false
            endswitch

          endif
        case retval = "Up" or retval = "PgUp":
          if isformview() then
            ctrlpgup
          else
            up
          endif
        case retval = "Down" or retval = "PgDn":
          if isformview() then
            ctrlpgdn
          else
            down
          endif

        ; * * * * * * * * * * * * * * * * * * *  illegal keys
        case retval = "Dos":         beep
        case retval = "DosBig":      beep
        case retval = "Rotate":      beep

      endswitch

    endwhile

  else

    Msg("No records found with same ID root value",1,"reverse",1500,false)
    IDRootCount = 1
    if not isformview() then
      formkey
    endif
    return true

  endif

endproc

writelib LIBNAME CheckDupeID
release procs CheckDupeID
? "CheckDupeID()"
if row() >= 23 then setmargin 40 @ 1,0 endif




; ---------------------------------------------------------------------------
;                              ADD ID NUMBER
; ---------------------------------------------------------------------------
proc AddIDNbr()
  private x
  CurrentProc = "AddIDNbr"
  ; --------------------------------- assign rest of ID number
  if IDRootCount < 10 then
    ID = ID + "0" + strval(IDRootCount)
  else
    ID = ID + strval(IDRootCount)
  endif
  imagerights
  ins
  [Buyer ID] = ID
  [Lname] = Lname
  [Fname] = Fname
  moveto [Business]                 ; go to next field to be filled in
endproc

writelib LIBNAME AddIDNbr
release procs AddIDNbr
? "AddIDNbr()"
if row() >= 23 then setmargin 40 @ 1,0 endif

